function spiderWebObj(elId){
    this.elId = elId;
    this.graphColor = '#6bce00';
    this.fontColor = '#004f04';
    this.axisCount = 8;
    this.gradingCount = 10;
    this.gap = 60;
    this.results = [];
    this.previewResults = [];  
	this.hidden = false;
    
    /** Params set at variables.js **/
    this.axisNameLength = Params.Graph.axisNameLength || 150;
    this.axisNameFontSize = Params.Graph.axisNameFontSize || 18;
    this.gradingLineLength = Params.Graph.gradingLineLength || 5;
    this.gradingFontSize = Params.Graph.gradingFontSize || 10;
    this.circleR = Params.Graph.circleR || 9;
    this.circleActiveZone = Params.Graph.circleActiveZone || 13;

    
    this.axis = [];
    this.resultCircles = [];
    this.svgResultLines = [];
    
    this.resizeEnabled = true;
    
    this.svgns = "http://www.w3.org/2000/svg";
    
    this.init = function(){
		this.previewMode = (this.previewResults.length != 0);
        if (this.previewMode) this.gap = this.gap + 20;
        
		this.spiderWeb = document.getElementById(this.elId);
        this.spiderWeb.style.height = window.screenResize.containerHeight + 'px';
        
        this.mySvg = document.createElementNS(this.svgns, "svg");
        this.mySvg.setAttribute("xmlns", this.svgns);
        this.mySvg.setAttribute("version", "1.2");
        this.mySvg.setAttribute("baseProfile", "tiny");
        
        this.svgGroup = document.createElementNS(this.svgns, "g");
        this.mySvg.appendChild(this.svgGroup);
        
        this.spiderWeb.appendChild(this.mySvg);        
    
        this.getContainerDimensions();
        
        this.countAxis();
        this.drawAxises();
        
        if (window.spiderWeb.axisNames.length == 0 || window.spiderWeb.axisNames.length != this.axisCount)
            this.generateAxisNames();
            
        //if (!this.previewMode) this.initAxisNameEditor();
        this.drawAxisNames();        
        
        if (!this.previewMode){     
            this.countResultLine();
            this.drawResultLine();
            this.drawGradeTriggers();
        } else {
            this.drawPreview();
        }
        
        this.resizeGraph();
    };
    
    this.redrawGraph = function(){
        if (!this.resizeEnabled) return;
		this.svgGroup.setAttribute("transform", "");
        this.svgGroup.removeAttribute("transform");
		
        this.spiderWeb.style.height = window.screenResize.containerHeight + 'px';
        
        this.getContainerDimensions();
        this.countAxis();
        this.redrawAxises();
        this.redrawAxisNames();
        this.redrawResultLine();
        this.redrawResultCircles();
        if (!this.previewMode) this.redrawGradeTriggers();
        else this.redrawGraphNames();
        
        this.resizeGraph();
    };
    
    this.getContainerDimensions = function(){
        this.containerWidth = this.spiderWeb.offsetWidth;
        this.containerHeight = this.spiderWeb.offsetHeight;
        
        this.centerPoint = [this.containerWidth / 2, this.containerHeight / 2];
        
        if (this.previewMode) this.centerPoint[1] = this.centerPoint[1] - 20;
        
        this.radius = (this.containerWidth >= this.containerHeight) ? this.containerHeight/2-this.gap : this.containerWidth/2-this.gap;
    };
    
    this.drawPreview = function(){    
        this.resultCircles = [];
        window.spiderWeb.webPreviewEyeContainer.html('');
        for (var el = 0, node; node = this.mySvg.childNodes[el], el < this.mySvg.childNodes.length; el++){
            if (node.tagName == 'text')
                this.mySvg.removeChild(node);
        }
        
        for (i in this.previewResults){
            this.results = this.previewResults[i].results;
            this.graphColor = this.previewResults[i].graphColor;
            this.drawResultLine();
        }
		this.drawGraphNames();
        this.adjustCircleSize();
        if (window.spiderWeb.graphType == 0){
            this.hideOverlay();
        }
    };
	
	this.drawGraphNames = function(){
        this.graphNameHolder = document.createElementNS(this.svgns, "text");
		this.graphNameHolder.setAttributeNS(null, "x", '-10');
		this.graphNameHolder.setAttributeNS(null, "y", this.radius + this.gap);
		this.graphNameHolder.setAttributeNS(null, "font-size", '14');
		this.graphNameHolder.setAttributeNS(null, "text-anchor", 'middle');
		this.graphNameHolder.setAttributeNS(null, "class", 'graph-names');
		
		for (var nr in window.spiderWeb.graphNames){
			var graphName = this.createGraphName(nr);
			this.graphNameHolder.appendChild(graphName);
			this.previewResults[nr].graphName = graphName;
            this.createGraphEye(nr);
		}
		
		this.mySvg.appendChild(this.graphNameHolder);
		
		var transformList = this.graphNameHolder.transform.baseVal;
        var translate = this.mySvg.createSVGTransform();
        translate.setTranslate((this.centerPoint[0]), this.centerPoint[1]);
        transformList.appendItem(translate);
        transformList.consolidate();
		
		this.adjustGraphNameLength(this.graphNameHolder);
	};
    
    this.redrawGraphNames = function(){
        this.restoreGraphNames();
        this.graphNameHolder.setAttribute("transform", "");
        this.graphNameHolder.removeAttribute("transform");
        
        this.graphNameHolder.setAttributeNS(null, "y", this.radius + this.gap);
        var transformList = this.graphNameHolder.transform.baseVal;
        var translate = this.mySvg.createSVGTransform();
        translate.setTranslate((this.centerPoint[0]), this.centerPoint[1]);
        transformList.appendItem(translate);
        transformList.consolidate();
        this.adjustGraphNameLength(this.graphNameHolder);
    };
	
		this.createGraphName = function(nr){
			var self = this;
			var graphName = document.createElementNS(this.svgns, "tspan");
			graphName.setAttributeNS(null, "dx", '10');
			graphName.setAttributeNS(null, "fill", this.previewResults[nr].fontColor);
			
			textNode = document.createTextNode(window.spiderWeb.graphNames[nr]);
            graphName.appendChild(textNode);          
			
			return graphName;
		};
        
        this.createGraphEye = function(nr){
            var self = this,
                graphEye = document.createElement('a'),
                className = this.previewResults[nr].eyeClassName;
            
            graphEye.href = "javascript:void(0)";
            graphEye.className = className + ((window.spiderWeb.spiderWebGraphs[nr].hidden) ? ' hidden' : '');
            
            graphEye.addEventListener('click', function(e){
                var action = self.toggleGraph(nr);
                if (action == 'hide'){
                    graphEye.className = className + ' hidden';
                } else {
                    graphEye.className = className;
                }
            });
            
            if (window.spiderWeb.spiderWebGraphs[nr].hidden){
                this.hideGraph(nr);
            }
            window.spiderWeb.webPreviewEyeContainer.append(graphEye);
        };
        
        this.restoreGraphNames = function(){
            for (var n = 0, graph; graph = this.previewResults[n];  n++){
                graph.graphName.textContent = window.spiderWeb.graphNames[n];
            }
        };
		
		this.adjustGraphNameLength = function(graphNameHolder){
			while(this.containerWidth < graphNameHolder.getBoundingClientRect().width){
				var graphNames = [];
                for (var n in this.previewResults){
                    var text = this.previewResults[n].graphName.textContent;
                    text = text.split("...")[0];
                    graphNames.push(text);
				}
                
                var longestNameLength = 0;
                for (var t in graphNames){
                    longestNameLength = (longestNameLength < graphNames[t].length) ? graphNames[t].length : longestNameLength;
                }
                
                for (var t in graphNames){
                    if (longestNameLength == graphNames[t].length){
                        graphNames[t] = graphNames[t].substring(0, graphNames[t].length - 1)  + '...';
                    }
                    this.previewResults[t].graphName.textContent = graphNames[t];
                }
			}
		};
    
    this.findValueCountInArray = function(array, value){    
        var result = 0;
        for (var i in array){
            if (array[i] == value) result++;
        }
        return result;
    };
    
    this.adjustCircleSize = function(){
        var combinedCircles = [],
            self = this;     
            
        for (var i = this.resultCircles.length-1; i>=0; i--){
            if (!window.spiderWeb.spiderWebGraphs[i].hidden){
                for (var c in this.resultCircles[i]){ 
                    var circle = this.resultCircles[i][c],
                        position = circle.getAttribute('transform');
                    
                    var groupChildren = circle.childNodes;
                    for (var ch in groupChildren)
                        if (groupChildren[ch].tagName == 'circle')
                            groupChildren[ch].setAttributeNS(null, "r",  this.circleR + this.findValueCountInArray(combinedCircles, position)*2.5);
                      
                    combinedCircles.push(position);
                }
            }
        }
    };
    
    this.toggleGraph = function(n){
        if (!this.previewMode) return;
        
		var result = '';
        if (window.spiderWeb.spiderWebGraphs[n].hidden){
            this.showGraph(n);
			result = 'show';
        } else {
            this.hideGraph(n);
			result = 'hide';
		}
            
        this.adjustCircleSize();
		return result;
    };
    
    this.hideGraph = function(n){
        this.svgResultLines[n].setAttributeNS(null, "opacity", 0);
		this.previewResults[n].graphName.setAttributeNS(null, "fill-opacity", "0.3");
        window.spiderWeb.spiderWebGraphs[n].hidden = true;
    };
    
    this.showGraph = function(n){
        this.svgResultLines[n].setAttributeNS(null, "opacity", 1);
        this.previewResults[n].graphName.setAttributeNS(null, "fill-opacity", 1);
        window.spiderWeb.spiderWebGraphs[n].hidden = false;
    };
    
    this.hideOverlay = function(){
        if (!this.previewMode) return;
        for (var l in this.svgResultLines){
            children = this.svgResultLines[l].childNodes;
            for (var i in children){
                if (children[i].tagName == 'path'){
                    children[i].setAttributeNS(null, "fill-opacity", 0);
                }
            }
        }
    };
    
    this.showOverlay = function(){
        if (!this.previewMode) return;
        for (var l in this.svgResultLines){
            children = this.svgResultLines[l].childNodes;
            for (var i in children){
                if (children[i].tagName == 'path'){
                    children[i].setAttributeNS(null, "fill-opacity", 0.1);
                }
            }
        }
    };
    
    this.countAxis = function(){
        this.axis = [];
        angle = 360/this.axisCount;
        for (var i = 0; i < this.axisCount; i++){
            xAngl = 90+angle*i;
            x = 0 - (this.radius * Math.cos((xAngl * Math.PI/180))).toFixed(2)*1;
            yAngl = xAngl+90;
            y = 0 - (this.radius * Math.cos((yAngl * Math.PI/180))).toFixed(2)*-1;
            this.axis.push({
                endPoint: [x, y], 
                gradingPoints: this.countAxisGradings(xAngl, yAngl)
            });
        }
    };
    
    this.countAxisGradings = function(xAngl, yAngl){
        var gradings = {points: [], lines: []};
        for (var i = 0; i < this.gradingCount; i++){
            x = 0 - (this.radius/this.gradingCount*(i+1) * Math.cos((xAngl * Math.PI/180))).toFixed(2)*1;
            y = 0 - (this.radius/this.gradingCount*(i+1) * Math.cos((yAngl * Math.PI/180))).toFixed(2)*-1;
            
            x1 = x - (-this.gradingLineLength/2 * Math.cos(((xAngl-90) * Math.PI/180))).toFixed(2)*1;
            y1 = y - (-this.gradingLineLength/2 * Math.cos(((yAngl-90) * Math.PI/180))).toFixed(2)*-1;            
            x2 = x - (this.gradingLineLength/2 * Math.cos(((xAngl-90) * Math.PI/180))).toFixed(2)*1;
            y2 = y - (this.gradingLineLength/2 * Math.cos(((yAngl-90) * Math.PI/180))).toFixed(2)*-1;
            gradings.points.push([x,y]);
            gradings.lines.push({start: [x1,y1], end: [x2,y2]});
        }
        
        return gradings;
    };
    
    this.drawAxises = function(){
        this.axisSVG = [];
        for (var i in this.axis){
            this.axisSVG.push({axis: {}, axisPoints: [], axisPointLines: []});
            this.drawAxis(i);
            this.drawAxisGradingPointLines(i);
            
            //if (i == 0) this.drawAxisNumbers();
        }
    };
    
    this.redrawAxises = function(){
		for (var i in this.axisSVG){
            var axis = this.axisSVG[i].axis;
            axis.setAttributeNS(null, "x1", 0);
            axis.setAttributeNS(null, "y1", 0);
            axis.setAttributeNS(null, "x2", this.axis[i].endPoint[0]);
            axis.setAttributeNS(null, "y2", this.axis[i].endPoint[1]);
            this.redrawAxisGradingPointLines(i);            
        }
    };
    
    this.drawAxis = function(axisNr){
        var axis = document.createElementNS(this.svgns, "line");
        axis.setAttributeNS(null, "x1", 0);
        axis.setAttributeNS(null, "y1", 0);
        axis.setAttributeNS(null, "x2", this.axis[axisNr].endPoint[0]);
        axis.setAttributeNS(null, "y2", this.axis[axisNr].endPoint[1]);
        axis.setAttributeNS(null, "stroke", "#9a9a9a");
        this.svgGroup.appendChild(axis);
        this.axisSVG[axisNr].axis = axis;
    };
    
    this.drawAxisNumbers = function(){
        for (var i = 0; i < this.axis[0].gradingPoints.points.length; i++ ){
            coords = this.axis[0].gradingPoints.points[i];
            text = document.createElementNS(this.svgns, "text");
            text.setAttributeNS(null, "x", coords[0]-5);
            text.setAttributeNS(null, "y", coords[1]+3);
            text.setAttributeNS(null, "font-size", '11');
            text.setAttributeNS(null, "fill", '#666666');
            text.setAttributeNS(null, "text-anchor", 'end');
            textNode = document.createTextNode(parseInt(i)+1);
            text.appendChild(textNode);                     
            this.svgGroup.appendChild(text);
        }
    };
    
    this.generateAxisNames = function(){
        for (var i=0; i < this.axisCount; i++)
            window.spiderWeb.axisNames[i] = window.spiderWeb.defaultAxisName;
    };
    
    this.findAxisNamePosition = function(i){
        var x = this.axis[i].endPoint[0];
        var y = this.axis[i].endPoint[1];
		
        if (x < 0) x -= 10;
        else if (x > 0) x += 10;
		
		if (x == 0 && y < 0) y = y - this.axisNameObjs[i].getBoundingClientRect().height - 5;
		if (y > 0) y += 15;		
		if (y == 0) y += 10;
		
		if (x != 0) y = y - this.axisNameObjs[i].getBoundingClientRect().height / 2
        
        return [x,y + 5];
    };
    
    this.drawAxisNames = function(){
        this.axisNameObjs = [];      
        for (var i in this.axis){
            var text = document.createElementNS(this.svgns, "text");
			
            text.setAttributeNS(null, "font-size", this.axisNameFontSize);
            text.setAttributeNS(null, "fill", '#333333');
            if (0 == this.axis[i].endPoint[0])
                text.setAttributeNS(null, "text-anchor", 'middle');
            else if (0 > this.axis[i].endPoint[0])
                text.setAttributeNS(null, "text-anchor", 'end');
             
            this.svgGroup.appendChild(text);
            
            this.axisNameObjs[i] = text;
            if (!this.previewMode) this.initAxisName(text, i);
            
			var position = this.findAxisNamePosition(i);
			this.editAxisName(i, position[0]);
			position = this.findAxisNamePosition(i);
            text.setAttributeNS(null, "x", position[0]);
            text.setAttributeNS(null, "y", position[1]);
        }        
    };
    
    this.redrawAxisNames = function(){
        for (var t = 0, text; text = this.axisNameObjs[t]; t++){
            var position = this.findAxisNamePosition(t);
            text.setAttributeNS(null, "x", position[0]);
            text.setAttributeNS(null, "y", position[1]);
			
			children = text.childNodes;
            for (var i in children){
				if (children[i].tagName == 'tspan')
					children[i].setAttributeNS(null, "x", position[0]);
			}
        }
    };
    
    this.initAxisName = function(element, n){
        var self = this;
        
        element.addEventListener("click", function(){
            window.dialog.openDialog(
                'dialog-edit-axis-name', 
                {
                    name: (window.spiderWeb.defaultAxisName == window.spiderWeb.axisNames[n]) ? '' : window.spiderWeb.axisNames[n],
                    n: n,
                    maxlength: self.axisNameLength
                },
                self
            );
            
            /*
            var textAnchor = self.axisNameObjs[n].getAttribute('text-anchor');
            self.axisNameEditor.value = (window.spiderWeb.defaultAxisName == window.spiderWeb.axisNames[n]) ? '' : window.spiderWeb.axisNames[n];
            self.axisNameEditor.setAttribute("name", n);   
            //self.axisNameObjs[n].setAttributeNS(null, "opacity", 0);   
            self.axisNameEditor.className = textAnchor;
            self.axisNameEditor.style.display = "block";
            
			self.resizeEnabled = false;
			self.axisNameEditor.focus();
			return;
			
            var inputWidth = self.axisNameObjs[n].getBoundingClientRect().width*self.graphScale;
            inputWidth = 150;
            self.axisNameEditor.style.width = inputWidth + 'px';
            
            var marginLeft = 0;
            if (textAnchor == 'end') marginLeft = (inputWidth*-1) - 10 * self.graphScale;
            else if (textAnchor == 'middle') marginLeft = (inputWidth*-1/2) - 5 * self.graphScale;      
            self.axisNameEditor.style.marginLeft = marginLeft + 'px';
            
            self.axisNameEditor.style.top = (self.centerPoint[1] + self.axisNameObjs[n].getAttribute('y')*1*self.graphScale + self.graphMovePointY) + "px";
            self.axisNameEditor.style.left = (self.centerPoint[0] + self.axisNameObjs[n].getAttribute('x')*1*self.graphScale + self.graphMovePointX) + "px";
            self.axisNameEditor.focus();
			self.axisNameEditor.style.height = 'auto';
			self.axisNameEditor.style.height = self.axisNameEditor.scrollHeight+'px';
            self.resizeEnabled = false;
            */
        }, false); 
    };
    
    /*
    this.initAxisNameEditor = function(){
        var self = this;
        
        this.axisNameEditor = document.createElement("textarea");
        //this.axisNameEditor = document.createElement("input");
        //this.axisNameEditor.setAttribute('type', 'text');

        this.axisNameEditor.setAttribute('maxlength', this.axisNameLength);
        this.spiderWeb.appendChild(this.axisNameEditor);
        
        // this.axisNameEditor.addEventListener("keyup", function(e){
		// 	self.axisNameEditor.style.height = 'auto';
		// 	self.axisNameEditor.style.height = self.axisNameEditor.scrollHeight+'px';
        // });
        
        this.axisNameEditor.onblur = function(){
            var defaultName = (self.axisNameEditor.value.match(/\S/) == null);
            window.spiderWeb.axisNames[this.name] =  (defaultName) ? window.spiderWeb.defaultAxisName : self.axisNameEditor.value;
            self.axisNameObjs[this.name].setAttributeNS(null, "opacity", 1);
            self.editGraphsAxisNames(this.name);
            this.style.display = "none";
            self.resizeEnabled = true;
            
            window.screenResize.resizeContainer();
            self.redrawGraph();
        };
    };
    */
    
    this.saveAxisName = function(n, axisName){
        axisName = $.trim(axisName);
        var defaultName = (axisName.match(/\S/) == null);
        window.spiderWeb.axisNames[n] = (defaultName) ? window.spiderWeb.defaultAxisName : axisName;
        this.editGraphsAxisNames(n);
        this.resizeEnabled = true;
        window.screenResize.resizeContainer();
        this.redrawGraph();
    };
    
    this.editAxisName = function(axisNr, positionX){
		var axisName = this.axisNameObjs[axisNr];
		this.createAxisNameRows(axisName, window.spiderWeb.axisNames[axisNr], positionX);        		
    };
	
	this.editGraphsAxisNames = function(axisNr){
		for (var graph in window.spiderWeb.spiderWebGraphs){
			var axisName = window.spiderWeb.spiderWebGraphs[graph].axisNameObjs[axisNr];
			this.createAxisNameRows(axisName, window.spiderWeb.axisNames[axisNr]);
		}
    };
	
	this.createAxisNameRows = function(parent, axisName, positionX){
		while (parent.firstChild) {
			parent.removeChild(parent.firstChild);
		}
		
		var axisNameArr = axisName.split('\n');
		for (var i in axisNameArr){
			var textNode = document.createTextNode((axisNameArr[i] == '') ? '\u00A0' : axisNameArr[i]);
			var tspan = document.createElementNS(this.svgns, "tspan");
			tspan.setAttributeNS(null, "x", (typeof positionX != 'undefined') ? positionX : parent.getAttribute('x'));
			tspan.setAttributeNS(null, "dy", (i == 0) ? '0' : "1.2em");
			tspan.appendChild(textNode);		
			parent.appendChild(tspan);
		}
	};
    
    this.browserTransforms = function(x, y, scale){
        var arr = [
            '-moz-transform: translate('+x+'px, '+y+'px) scale('+scale+');',
            '-webkit-transform: translate('+x+'px, '+y+'px) scale('+scale+');',
            '-o-transform: translate('+x+'px, '+y+'px) scale('+scale+');',
            '-ms-transform: translate('+x+', '+y+') scale('+scale+');',
            'transform: translate('+x+'px, '+y+'px) scale('+scale+');'
        ];
        
        return arr.join('');
    };
	
	this.resizeGraph = function(){
        
        var rightPoint = 0,
            leftPoint = 0,
            topPoint = 0,
            bottomPoint = 0;
        
        for (var name in this.axisNameObjs){
            var pointX = Math.abs(this.axisNameObjs[name].getAttribute('x')) + this.axisNameObjs[name].getBoundingClientRect().width,
                pointY = parseInt(this.axisNameObjs[name].getAttribute('y'));
            
            if (this.axisNameObjs[name].getAttribute('text-anchor') == null)
                rightPoint = (rightPoint > pointX) ? rightPoint : pointX;
                
            if (this.axisNameObjs[name].getAttribute('text-anchor') == 'end')
                leftPoint = (leftPoint > pointX) ? leftPoint : pointX;
            
            if (this.axis[name].endPoint[1] < 0){
				topPoint = (topPoint < pointY) ? topPoint : pointY;
            } else {
				pointY += this.axisNameObjs[name].getBoundingClientRect().height;
				bottomPoint = (bottomPoint > pointY) ? bottomPoint : pointY;    
			}
		}
        
        topPoint = Math.abs(topPoint);
        bottomPoint = Math.abs(bottomPoint);
        
        var containerWidth = this.containerWidth - this.gap,
            containerHeight = this.containerHeight - this.gap;

		var graphWidth = this.svgGroup.getBoundingClientRect().width,
			graphHeight = this.svgGroup.getBoundingClientRect().height;
			
		widthScale = containerWidth / graphWidth;
		heightScale = containerHeight / graphHeight;
		
		this.graphScale = (widthScale < heightScale) ? widthScale : heightScale;
        
		this.graphMovePointX = Math.abs((leftPoint - rightPoint)/2 * this.graphScale);
        if (leftPoint < rightPoint) this.graphMovePointX = this.graphMovePointX*-1;
        
        this.graphMovePointY = Math.abs((topPoint - bottomPoint)/2 * this.graphScale);
        if (topPoint < bottomPoint) this.graphMovePointY = this.graphMovePointY*-1;
		
        var transformList = this.svgGroup.transform.baseVal;
        //--- reuse a single transform request---
        var translate = this.mySvg.createSVGTransform();
        translate.setTranslate((this.centerPoint[0]+this.graphMovePointX), this.centerPoint[1]+this.graphMovePointY);
        
        var scale = this.mySvg.createSVGTransform();
        scale.setScale(this.graphScale,this.graphScale);
        transformList.appendItem(translate);
        transformList.appendItem(scale);
        
        //---creates a transform matrix, replacing all previous ---
        transformList.consolidate();
    };
    
    this.drawAxisGradingPointLines = function(axisNr){
        for (var g = 0, point; point = this.axis[axisNr].gradingPoints.lines[g]; g++){
            this.drawGradingPointLine(axisNr, point);
        }
    };
    
    this.redrawAxisGradingPointLines = function(axisNr){
        for (var g = 0, line; line = this.axisSVG[axisNr].axisPointLines[g]; g++){
            line.setAttributeNS(null, "x1", this.axis[axisNr].gradingPoints.lines[g].start[0]);
            line.setAttributeNS(null, "y1", this.axis[axisNr].gradingPoints.lines[g].start[1]);
            line.setAttributeNS(null, "x2", this.axis[axisNr].gradingPoints.lines[g].end[0]);
            line.setAttributeNS(null, "y2", this.axis[axisNr].gradingPoints.lines[g].end[1]);
        }        
    };
    
    this.drawGradingPointLine = function(axisNr, gradingPoint){
        var axis = document.createElementNS(this.svgns, "line");
        axis.setAttributeNS(null, "x1", gradingPoint.start[0]);
        axis.setAttributeNS(null, "y1", gradingPoint.start[1]);
        axis.setAttributeNS(null, "x2", gradingPoint.end[0]);
        axis.setAttributeNS(null, "y2", gradingPoint.end[1]);
        axis.setAttributeNS(null, "stroke", "#9a9a9a");
        this.svgGroup.appendChild(axis);    
        this.axisSVG[axisNr].axisPointLines.push(axis);
    };
    
    this.drawGradeTriggers = function(){
        this.gradeTriggersSVG = [];
        for (var axis=0; axis < this.axisCount; axis++){           
            this.gradeTriggersSVG[axis] = []; 
            for (var grade=0; grade < this.gradingCount; grade++){                            
                var gradingPoint = this.axis[axis].gradingPoints.points[grade];
                
                group = document.createElementNS(this.svgns, "g");
                group.setAttributeNS(null, "transform", "translate(" + gradingPoint[0] + "," + gradingPoint[1] + ")");
                group.setAttributeNS(null, "opacity",  "0");
                group.setAttributeNS(null, "class",  "cursor-pointer");
                
                gradeTrigger = document.createElementNS(this.svgns, "circle");
                gradeTrigger.setAttributeNS(null, "cx", 0);
                gradeTrigger.setAttributeNS(null, "cy", 0);
                gradeTrigger.setAttributeNS(null, "r",  this.circleActiveZone);
                gradeTrigger.setAttributeNS(null, "fill",  'white');
                gradeTrigger.setAttributeNS(null, "stroke",  this.graphColor);
                gradeTrigger.setAttributeNS(null, "stroke-width",  3);
                group.appendChild(gradeTrigger);  
                
                text = document.createElementNS(this.svgns, "text");
                text.setAttributeNS(null, "x", 0);
                text.setAttributeNS(null, "y", 4);
                text.setAttributeNS(null, "font-size", this.gradingFontSize);
                text.setAttributeNS(null, "fill", 'black');
                text.setAttributeNS(null, "text-anchor", 'middle');
                textNode = document.createTextNode(grade+1);
                text.appendChild(textNode);
                group.appendChild(text);                
                           
                this.svgGroup.appendChild(group);
                
                this.initGradeTrigger(group, axis, grade);
                this.gradeTriggersSVG[axis].push(group);
            }
        }        
    };
    
    this.redrawGradeTriggers = function(){
        for (var a = 0, axis; axis = this.axis[a]; a++){
            for (var p = 0, point; point = axis.gradingPoints.points[p]; p++){
                this.gradeTriggersSVG[a][p].setAttributeNS(null, "transform", "translate(" + point[0] + "," + point[1] + ")");;
            }
        }
    };
    
    this.initGradeTrigger = function(gradeTrigger, axis, grade){
        var self = this;
        gradeTrigger.addEventListener("click", function(){
            self.editResultLine(axis, grade);
            this.setAttributeNS(null, "opacity",  "0");
            Circle(this).setAttributeNS(null, "r",  self.circleActiveZone);
        }, false); 
        
        gradeTrigger.addEventListener("mouseover", function(){
            if (self.results[axis] != grade){
                this.setAttributeNS(null, "opacity",  "1");
                Circle(this).setAttributeNS(null, "r",  self.circleR - 1);
            }
        }, false);  
        
        gradeTrigger.addEventListener("mouseout", function(){
            this.setAttributeNS(null, "opacity",  "0");
            Circle(this).setAttributeNS(null, "r",  self.circleActiveZone);
        }, false);   
        
        function Circle(parent){
            var child = parent.children;
            for (c in child){
                if (child[c].tagName == 'circle'){
                    return child[c];
                }
            }
        }
    };
    
    this.generateResultLinePath = function(){
        resultString = "";
        
        for (var i in this.results){
            if (i == 0) resultString += "M";
            else resultString += " L";
			
			//if (typeof this.axis[i].gradingPoints[this.results[i]] != 'undefined')
				resultString += this.axis[i].gradingPoints.points[this.results[i]].join(',');
        }        
		resultString += " L" + this.axis[0].gradingPoints.points[this.results[0]].join(',');
			
        return resultString;
    };
    
    this.drawResultLine = function(){
        var group = document.createElementNS(this.svgns, "g");
        svgResultLine = document.createElementNS(this.svgns, "path");
        svgResultLine.setAttributeNS(null, "d", this.generateResultLinePath());
        svgResultLine.setAttributeNS(null, "fill", this.graphColor);
        svgResultLine.setAttributeNS(null, "fill-opacity", (!this.previewMode) ? "0" : "0.1");
        svgResultLine.setAttributeNS(null, "stroke", this.graphColor);
        svgResultLine.setAttributeNS(null, "stroke-width", "3");
        group.appendChild(svgResultLine);
        
        resultCircles = this.drawResultCircles();
        
        for (var i in resultCircles)
            group.appendChild(resultCircles[i]);
        
        this.svgGroup.appendChild(group);
        
        this.svgResultLines.push(group);
    };
    
    this.countResultLine = function(){  
        if (this.results.length == 0 || this.results.length != this.axisCount){
			this.results = [];
			for(var i=0; i <this.axisCount; i++)
				this.results.push(0);
		} else {
			for(var i=0; i <this.axisCount; i++){
				if (typeof this.axis[i].gradingPoints.points[this.results[i]] == 'undefined')
					this.results[i] = 0;
			}
		}
    };
    
    this.editResultLine = function(axisNr, pointNr){
        this.results[axisNr] = parseInt(pointNr);
        this.editResultNumber(axisNr, pointNr);         
        this.redrawResultLine();
        this.redrawResultCircle(axisNr, pointNr);
    };
    
    this.redrawResultLine = function(){
        for (var l = 0, resultLine; resultLine = this.svgResultLines[l]; l++){
            children = resultLine.childNodes;
            if (this.previewMode) this.results = this.previewResults[l].results;
            for (var i in children){
                if (children[i].tagName == 'path'){
                    children[i].setAttributeNS(null, "d", this.generateResultLinePath());
                }
            }
        }
    };
    
    this.drawResultCircles = function(){
        var resultCircles = []; 
             
        for (var i in this.results){
			var gradingPoint = this.axis[i].gradingPoints.points[this.results[i]];
            coords = (typeof gradingPoint != 'undefined') ? gradingPoint : this.axis[i].gradingPoints.points[0];
            
            group = document.createElementNS(this.svgns, "g");
            group.setAttributeNS(null, "transform", "translate(" + coords[0] + "," + coords[1] + ")");
            
            circle = document.createElementNS(this.svgns, "circle");
            circle.setAttributeNS(null, "cx", 0);
            circle.setAttributeNS(null, "cy", 0);
            circle.setAttributeNS(null, "r",  this.circleR);
            circle.setAttributeNS(null, "fill",  this.graphColor);
            
            text = document.createElementNS(this.svgns, "text");
            text.setAttributeNS(null, "x", 0);
            text.setAttributeNS(null, "y", 4);
            text.setAttributeNS(null, "font-size", this.gradingFontSize);
            text.setAttributeNS(null, "fill", "white");
            text.setAttributeNS(null, "text-anchor", 'middle');
            textNode = document.createTextNode((this.gradingCount <= this.results[i]) ? 1 : this.results[i] + 1);
            text.appendChild(textNode);
            group.appendChild(text); 
            
            group.appendChild(circle);
            group.appendChild(text);
            resultCircles.push(group);
        }
        this.resultCircles.push(resultCircles);
        return resultCircles;
    };
    
    this.redrawResultCircles = function(){
        if (!this.previewMode){
            for (var a = 0, axis; axis = this.axis[a]; a++){
                this.redrawResultCircle(a, this.results[a]);
            }
        } else {
            for (var previewGraphNr = 0; previewGraphNr < this.svgResultLines.length; previewGraphNr++){
                for (var a = 0, axis; axis = this.axis[a]; a++){
                    this.redrawResultCircle(a, this.previewResults[previewGraphNr].results[a], previewGraphNr);
                }
            }
        }
    };
    
    this.redrawResultCircle = function(axisNr, pointNr, previewGraphNr){
        this.resultCircles[(previewGraphNr) ? previewGraphNr : 0][axisNr].setAttributeNS(null, "transform", "translate(" + this.axis[axisNr].gradingPoints.points[pointNr][0] + "," + this.axis[axisNr].gradingPoints.points[pointNr][1] + ")");
    };
        
    this.editResultNumber = function(axisNr, pointNr){
        children = this.resultCircles[0][axisNr].childNodes;
        for (i in children){
            if (children[i].tagName == 'text'){
                textNode = document.createTextNode(this.results[axisNr] + 1);
                children[i].removeChild(children[i].firstChild);
                children[i].appendChild(textNode);
            }
        }
    };
}