var spiderWeb = {
    axisCountChoice:    '.axisCountChoice a',
    axisGradingChoice:  '.axisGradingChoice a',
    axisCount:          3, // Default value
    gradingCount:       4, // Default value
    graphType:          1, // Default value | with overlay
    maximumGraphs:      6,
    saveButton:         'a#save-settings',
    createNew:          'a#create-new-web, a#create-new-web-start',
    btnBackFromLs:      'a#back-from-ls',
    previewButton:      'a#preview-button',
    closePreviewButton: 'a#close-preview-button',
    showPreviewOverlay: 'a#show-overlay',
    hidePreviewOverlay: 'a#hide-overlay',
    axisNames:          [],
    graphNames:         [],    
    defaultAxisName:    "Ašies pavadinimas",
    defaultGraphName:   "Naujas skirtukas",
	
	defaultProjectTitle: "Įrašykite pavadinimą",
	projectTitle: 		"",
	defaultProjectAuthor: "Įrašykite vardą ir pavardę",
	projectAuthor: 		"",
    //window.spiderWeb.defaultAxisName = window.spiderWeb.defaultAxisName;
    //window.spiderWeb.defaultGraphName = window.spiderWeb.defaultGraphName;
    
    graphColors: [
        {graphColor: '#6bce00', fontColor: '#004f04', used: false, eyeClassName: 'eye color0'}, 
        {graphColor: '#ff8800', fontColor: '#a85a00', used: false, eyeClassName: 'eye color1'}, 
        {graphColor: '#d00101', fontColor: '#aa0101', used: false, eyeClassName: 'eye color2'}, 
        {graphColor: '#9b12a4', fontColor: '#690c6f', used: false, eyeClassName: 'eye color3'}, 
        {graphColor: '#0274d0', fontColor: '#014277', used: false, eyeClassName: 'eye color4'}, 
        {graphColor: '#00bdb7', fontColor: '#006461', used: false, eyeClassName: 'eye color5'}
    ],
    
    tabHolder: '#graphTabs',   
    addGraphBtn: '#add-graph',
    
    webStartContainer: '#web-start',
    webSettingsContainer: '#web-settings',
    webLocalStorageContainer: '#web-local-storage',
    webEditContainer:   '#web-edit',
    webEditBoxContainer: '#web-edit .spiderweb-box',
    
    webPreviewContainer: '#web-preview',
    webPreviewBoxContainer: '#web-preview .spiderweb-box',
    webPreviewEyeContainer: '#preview-graph-eyes',
    
    activeTab: 0,
	spiderWebGraphs: [],
    spiderWebPreviewGraph: {},
    
    init: function(){
        this.tabHolder = $(this.tabHolder);
        this.addGraphBtn = $(this.addGraphBtn);
        
        this.webStartContainer = $(this.webStartContainer);
        this.webSettingsContainer = $(this.webSettingsContainer);
        this.webLocalStorageContainer = $(this.webLocalStorageContainer);
        this.webEditContainer = $(this.webEditContainer);
        this.webEditBoxContainer = $(this.webEditBoxContainer);
        
        this.webPreviewContainer = $(this.webPreviewContainer);
        this.webPreviewBoxContainer = $(this.webPreviewBoxContainer);
        this.webPreviewEyeContainer = $(this.webPreviewEyeContainer);
        
        this.initAxisChoice();
        this.initGradingChoice();
        
        this.loadGraphInit();
        
        this.initSettingsSave();
        this.initCreateNew();
        
        this.initAddNewGraphBtn();
        
        this.initPreviewButton();
        this.showHideOverlay.init();
        this.initClosePreviewButton();
		
		this._projectTitle.init();
		this._projectAuthor.init();
                
        this.adjustToScreen();
    },
    
    initAxisChoice: function(){
        var self = this,
            $choices = $(this.axisCountChoice);
        
        $choices.each(function(){
            var $choice = $(this),
                axisCount = $choice.data('axiscount');
                
            $choice.click(function(){
                self.axisCount = axisCount;
                $choices.removeClass('selected');
                $choice.addClass('selected');
            });
        });
    },
    
    initGradingChoice: function(){
        var self = this,
            $choices = $(this.axisGradingChoice);
        
        $choices.each(function(){
            var $choice = $(this),
                gradingCount = $choice.data('gradingcount');
                
            $choice.click(function(){
                self.gradingCount = gradingCount;
                $choices.removeClass('selected');
                $choice.addClass('selected');
            });
        });
    },
    
    initSettingsSave: function(){
        var self = this;
        $(this.saveButton).click(function(){
            self.webSettingsContainer.hide();
            self.webEditContainer.show();
            window.screenResize.resizeContainer();
            
            self.axisCount = $(self.axisCountChoice).filter('.selected').data('axiscount');
            self.gradingCount = $(self.axisGradingChoice).filter('.selected').data('gradingcount');            
               
            self.spiderWebGraphs = []; 
			self._projectTitle.change();
			self._projectAuthor.change();
            self.createGraph(0);
        });      
    },
    
    createGraph: function(n, data){
        var graph = this.createGraphHolder(n);  
        this.webEditBoxContainer.append(graph.holder);   
        this.spiderWebGraphs.push(new spiderWebObj(graph.id));
        if (!window.spiderWeb.graphNames[n])
            this.graphNames.push(this.defaultGraphName);
        this.spiderWebGraphs[n].axisCount = this.axisCount;
        this.spiderWebGraphs[n].gradingCount = this.gradingCount;
        
        var colors = this.getColors();
        this.spiderWebGraphs[n].graphColor = colors.graphColor;
        this.spiderWebGraphs[n].fontColor = colors.fontColor;
        this.spiderWebGraphs[n].eyeClassName = colors.eyeClassName;
        
        if (data){
            for (var set in data){
                this.spiderWebGraphs[n][set] = data[set];
            }
        }
        
        for (var i in this.spiderWebGraphs){
            if (i != n){
                this.spiderWebGraphs[i].spiderWeb.setAttribute('class', 'hide');    
            }
        }
        
        this.spiderWebGraphs[n].init();
        this.spiderWebGraphs[n].tab = new Tab(n);
    },
    
    deleteGraph: function(n){
        var newSpiderWebGraphs = [],
            graphNames = [],
            count = 0;
        for (var i in this.spiderWebGraphs){
            if (i != n){
                newSpiderWebGraphs.push(this.spiderWebGraphs[i]);
                this.spiderWebGraphs[i].tab.tabNr = count++;
                
                graphNames.push(this.graphNames[i]);
            } else {
                this.unreserveColors(this.spiderWebGraphs[i].graphColor, this.spiderWebGraphs[i].fontColor);
                
                var tab = this.spiderWebGraphs[n].tab.tab;
                tab.parentNode.removeChild(tab);
                
                var graph = this.spiderWebGraphs[i].spiderWeb;
                graph.parentNode.removeChild(graph);
            }
        }
        this.spiderWebGraphs = newSpiderWebGraphs;
        this.graphNames = graphNames;
        this.spiderWebGraphs[0].tab.showTab();
        this.addGraphBtn.toggle();
    },
    
    getColors: function(){
        var colors = {};
        for (var i in this.graphColors){
            if (!this.graphColors[i].used){
                colors = this.graphColors[i];
                this.graphColors[i].used = true;
                break;
            }
        }
        return colors;
    },
    
    unreserveAllColors: function(){
        for (var i in this.graphColors)
            this.graphColors[i].used = false;
    },
    
    unreserveColors: function(graphColor, fontColor){
        for (var i in this.graphColors){
            if (this.graphColors[i].graphColor == graphColor && this.graphColors[i].fontColor == fontColor){
                this.graphColors[i].used = false;
                break;
            }
        }
    },
    
    initCreateNew: function(){
        var self = this;
        $(this.createNew).click(function(e){
            if (this.getAttribute('data-confirm') == 'true'){
                window.dialog.openDialog('dialog-create-new');
            } else self.openCreateNew();
        });
    },
    
        clearCreatedGraphs: function(){
            this.webEditBoxContainer.html('');
            this.spiderWebGraphs = [];
            this.axisNames = [];
            this.graphNames = [];
			this.projectTitle = '';
			this.projectAuthor = '';
            this.graphType = 1;
            this.tabHolder.find('li').not(this.addGraphBtn).remove();
            this.unreserveAllColors();
            this.addGraphBtn.toggle();
        },
    
        openCreateNew: function(){
            this.clearCreatedGraphs();
                
            this.webSettingsContainer.show();
            this.webStartContainer.hide();
            this.webLocalStorageContainer.hide();
            this.webEditContainer.hide();
        },
    
    initAddNewGraphBtn: function(){
        var self = this;
        this.addGraphBtn.click(function(){
            self.createGraph(self.spiderWebGraphs.length);
            self.addGraphBtn.toggle();
        });
        
        this.addGraphBtn.toggle = function(){
            if (self.maximumGraphs == self.spiderWebGraphs.length)
                self.addGraphBtn.hide();
            else 
                self.addGraphBtn.show();
        }
        
        this.addGraphBtn.toggle();
    },
    
    initPreviewButton: function(){
        var self = this,
            $button = $(this.previewButton);
            
        $button.click(function(){
            self.webEditContainer.hide();
            self.webPreviewContainer.show();
            window.screenResize.resizeContainer();
            self.createPreviewGraph(); 
        });
    },
    
    createPreviewGraph: function(){
        var graph = this.createGraphHolder();    
        this.webPreviewBoxContainer.html(graph.holder);
        
        var previewResults = [],
            axisNames = [];
            
        for (var i in this.spiderWebGraphs){
            previewResults.push({
                results: this.spiderWebGraphs[i].results,
                hidden: this.spiderWebGraphs[i].hidden,
                graphColor: this.spiderWebGraphs[i].graphColor,
                eyeClassName: this.spiderWebGraphs[i].eyeClassName,
                fontColor: this.spiderWebGraphs[i].fontColor
            });
        }
        
        this.spiderWebPreviewGraph = new spiderWebObj(graph.id);
        this.spiderWebPreviewGraph.axisCount = this.axisCount;
        this.spiderWebPreviewGraph.gradingCount = this.gradingCount;            
        this.spiderWebPreviewGraph.previewResults = previewResults;            
        this.spiderWebPreviewGraph.axisNames = this.axisNames;            
        this.spiderWebPreviewGraph.init();
        this.showHideOverlay.toggleOverlay();
    },
    
    showHideOverlay: {
        init: function(){
            var self = this;
            this.spiderWeb = window.spiderWeb;
                
            this.$showBtn = $(this.spiderWeb.showPreviewOverlay);
            this.$hideBtn = $(this.spiderWeb.hidePreviewOverlay);     
            
            this.$showBtn.click(function(){
                self.spiderWeb.graphType = 1;
                self.toggleOverlay();
            }); 
            
            this.$hideBtn.click(function(){
                self.spiderWeb.graphType = 0;
                self.toggleOverlay();
            });      
        },
        
        toggleOverlay: function(){
            if (this.spiderWeb.graphType == 1){
                this.$hideBtn.removeClass('active');
                this.$showBtn.addClass('active');
                this.spiderWeb.spiderWebPreviewGraph.showOverlay();
            } else {
                this.$hideBtn.addClass('active');
                this.$showBtn.removeClass('active');
                this.spiderWeb.spiderWebPreviewGraph.hideOverlay();
            }
        }
    },
    
    initClosePreviewButton: function(){
        var self = this;
        $(this.closePreviewButton).click(function(){
            self.webEditContainer.show();
            self.webPreviewContainer.hide();
            self.webPreviewBoxContainer.html('');
            window.screenResize.resizeContainer();
            self.adjustToScreen();
        });
    },
    
    createGraphHolder: function(n){
        var time = new Date().getTime(),
            id = 'spiderWeb-' + ((n != 'undefined') ? n : '') + '-' + time,
            $webCont = $('<div>').attr('id', id);
            
        return {holder: $webCont, id: id};
    },
	
	_projectTitle: {
		init: function(){
			this._self = window.spiderWeb;
			this.$title = $('.head .title span');
			this.change();
			this.initTitle();
		},
		
		initTitle: function(){
			var self = this;
			this.$title.each(function(n, title){
				var $title = $(this);
				
				if ($title.siblings().length > 0){
					var $input = $title.siblings();
					$title.click(function(){
						$title.hide();
						$input.val(self._self.projectTitle);
						$input.show().focus();
					});
					
					$input.keyup(function(e){
						if (e.keyCode == 13)
							$input.blur();
					});
					
					$input.blur(function(){
						self._self.projectTitle = $.trim(this.value);
						self.change();
						$title.show();
						$input.hide();
					});
				}
			});
		},
		
		change: function(){
			this.$title.html((this._self.projectTitle != '') ? this._self.projectTitle : this._self.defaultProjectTitle);
		}
	},
	
	_projectAuthor: {
		init: function(){
			this._self = window.spiderWeb;
			this.$author = $('.head .author span');
			this.change();
			this.initAuthor();
		},
		
		initAuthor: function(){
			var self = this;
			this.$author.each(function(n, author){
				var $author = $(this);
				
				if ($author.siblings().length > 0){
					var $input = $author.siblings();
					$author.click(function(){
						$author.hide();
						$input.val(self._self.projectAuthor);
						$input.show().focus();
					});
					
					$input.keyup(function(e){
						if (e.keyCode == 13)
							$input.blur();
					});
					
					$input.blur(function(){
						self._self.projectAuthor = $.trim(this.value);
						self.change();
						$author.show();
						$input.hide();
					});
				}
			});
		},
		
		change: function(){
			this.$author.html((this._self.projectAuthor != '') ? this._self.projectAuthor : this._self.defaultProjectAuthor);
		}
	},
    
    adjustToScreen: function(){
        for (var g in this.spiderWebGraphs){
            var graph = this.spiderWebGraphs[g],
                $c = $(this.spiderWebGraphs[g].spiderWeb),
                visible = $c.is(':visible');
            
            if (visible){
                graph.redrawGraph();
            }    
        }
        
        if (this.spiderWebPreviewGraph.spiderWeb !== undefined)
            if($(this.spiderWebPreviewGraph.spiderWeb).is(":visible")){
                this.spiderWebPreviewGraph.redrawGraph();
            }
    },
    
    loadGraphInit: function(){
        var self = this;
        
        this.btnBackFromLs = $(this.btnBackFromLs);
        this.btnBackFromLs.click(function(){
            switch ($(this).data('history')){
                case "webEdit":
                    self.webEditContainer.show();
                    self.webLocalStorageContainer.hide();
                    break;
                
                case "webStart":
                    self.webStartContainer.show();
                    self.webLocalStorageContainer.hide();
                    break;
            }
        });
    },
    
    showLoadGraph: function(history){
        this.webLocalStorageContainer.show();
        
        if (history){
            this.btnBackFromLs.data('history', history);
        }
        
        window.lStorage.createList();
        
        this.webStartContainer.hide();
        this.webSettingsContainer.hide();
        this.webEditContainer.hide();
        this.webPreviewContainer.hide();
    }
}

$(function(){
    $.extend(spiderWeb, Params.Main);
    spiderWeb.init();
    lStorage.init();
    dialog.init();
    loadGraph.init();
	saveGraph.init();
    screenResize.init();
});